Documentation
¶
Index ¶
- Variables
- type DecapsRequest
- func (*DecapsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DecapsRequest) GetCiphertext() *proto.KemCiphertext
- func (x *DecapsRequest) GetKeyHandle() *proto.KeyHandle
- func (*DecapsRequest) ProtoMessage()
- func (x *DecapsRequest) ProtoReflect() protoreflect.Message
- func (x *DecapsRequest) Reset()
- func (x *DecapsRequest) String() string
- type DecapsResponse
- func (*DecapsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DecapsResponse) GetSharedSecret() *proto.KemSharedSecret
- func (*DecapsResponse) ProtoMessage()
- func (x *DecapsResponse) ProtoReflect() protoreflect.Message
- func (x *DecapsResponse) Reset()
- func (x *DecapsResponse) String() string
- type DestroyRequest
- type EnumerateKeysResponse
- func (*EnumerateKeysResponse) Descriptor() ([]byte, []int)deprecated
- func (x *EnumerateKeysResponse) GetKeyInfos() []*KeyInfo
- func (*EnumerateKeysResponse) ProtoMessage()
- func (x *EnumerateKeysResponse) ProtoReflect() protoreflect.Message
- func (x *EnumerateKeysResponse) Reset()
- func (x *EnumerateKeysResponse) String() string
- type GenerateKeyRequest
- func (*GenerateKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GenerateKeyRequest) GetAlgorithm() *proto.AlgorithmDetails
- func (x *GenerateKeyRequest) GetLifespan() uint64
- func (*GenerateKeyRequest) ProtoMessage()
- func (x *GenerateKeyRequest) ProtoReflect() protoreflect.Message
- func (x *GenerateKeyRequest) Reset()
- func (x *GenerateKeyRequest) String() string
- type GenerateKeyResponse
- func (*GenerateKeyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GenerateKeyResponse) GetExpirationTime() float64
- func (x *GenerateKeyResponse) GetKeyHandle() *proto.KeyHandle
- func (x *GenerateKeyResponse) GetKeyProtectionMechanism() string
- func (x *GenerateKeyResponse) GetPubKey() *proto.PubKeyInfo
- func (*GenerateKeyResponse) ProtoMessage()
- func (x *GenerateKeyResponse) ProtoReflect() protoreflect.Message
- func (x *GenerateKeyResponse) Reset()
- func (x *GenerateKeyResponse) String() string
- type GetCapabilitiesResponse
- func (*GetCapabilitiesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetCapabilitiesResponse) GetSupportedAlgorithms() []*proto.SupportedAlgorithm
- func (*GetCapabilitiesResponse) ProtoMessage()
- func (x *GetCapabilitiesResponse) ProtoReflect() protoreflect.Message
- func (x *GetCapabilitiesResponse) Reset()
- func (x *GetCapabilitiesResponse) String() string
- type KeyInfo
- func (*KeyInfo) Descriptor() ([]byte, []int)deprecated
- func (x *KeyInfo) GetExpirationTime() float64
- func (x *KeyInfo) GetKeyHandle() *proto.KeyHandle
- func (x *KeyInfo) GetKeyProtectionMechanism() string
- func (x *KeyInfo) GetPubKey() *proto.PubKeyInfo
- func (*KeyInfo) ProtoMessage()
- func (x *KeyInfo) ProtoReflect() protoreflect.Message
- func (x *KeyInfo) Reset()
- func (x *KeyInfo) String() string
Constants ¶
This section is empty.
Variables ¶
var File_workload_service_proto_api_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type DecapsRequest ¶
type DecapsRequest struct {
// The handle (UUID) of the KEM key instance to use for decapsulation.
KeyHandle *proto.KeyHandle `protobuf:"bytes,1,opt,name=key_handle,json=keyHandle,proto3" json:"key_handle,omitempty"`
// The encapsulated shared secret received from the client/proxy.
Ciphertext *proto.KemCiphertext `protobuf:"bytes,2,opt,name=ciphertext,proto3" json:"ciphertext,omitempty"`
// contains filtered or unexported fields
}
Request to perform a decapsulation operation using a specific key handle. (POST /v1/keys:decap)
func (*DecapsRequest) Descriptor
deprecated
func (*DecapsRequest) Descriptor() ([]byte, []int)
Deprecated: Use DecapsRequest.ProtoReflect.Descriptor instead.
func (*DecapsRequest) GetCiphertext ¶
func (x *DecapsRequest) GetCiphertext() *proto.KemCiphertext
func (*DecapsRequest) GetKeyHandle ¶
func (x *DecapsRequest) GetKeyHandle() *proto.KeyHandle
func (*DecapsRequest) ProtoMessage ¶
func (*DecapsRequest) ProtoMessage()
func (*DecapsRequest) ProtoReflect ¶
func (x *DecapsRequest) ProtoReflect() protoreflect.Message
func (*DecapsRequest) Reset ¶
func (x *DecapsRequest) Reset()
func (*DecapsRequest) String ¶
func (x *DecapsRequest) String() string
type DecapsResponse ¶
type DecapsResponse struct {
SharedSecret *proto.KemSharedSecret `protobuf:"bytes,1,opt,name=shared_secret,json=sharedSecret,proto3" json:"shared_secret,omitempty"`
// contains filtered or unexported fields
}
Response from a decapsulation operation.
func (*DecapsResponse) Descriptor
deprecated
func (*DecapsResponse) Descriptor() ([]byte, []int)
Deprecated: Use DecapsResponse.ProtoReflect.Descriptor instead.
func (*DecapsResponse) GetSharedSecret ¶
func (x *DecapsResponse) GetSharedSecret() *proto.KemSharedSecret
func (*DecapsResponse) ProtoMessage ¶
func (*DecapsResponse) ProtoMessage()
func (*DecapsResponse) ProtoReflect ¶
func (x *DecapsResponse) ProtoReflect() protoreflect.Message
func (*DecapsResponse) Reset ¶
func (x *DecapsResponse) Reset()
func (*DecapsResponse) String ¶
func (x *DecapsResponse) String() string
type DestroyRequest ¶
type DestroyRequest struct {
// The handle (UUID) of the keypair to destroy.
KeyHandle *proto.KeyHandle `protobuf:"bytes,1,opt,name=key_handle,json=keyHandle,proto3" json:"key_handle,omitempty"`
// contains filtered or unexported fields
}
Request to manually trigger the destruction of a keypair before its lifespan expires. (POST /v1/keys:destroy)
func (*DestroyRequest) Descriptor
deprecated
func (*DestroyRequest) Descriptor() ([]byte, []int)
Deprecated: Use DestroyRequest.ProtoReflect.Descriptor instead.
func (*DestroyRequest) GetKeyHandle ¶
func (x *DestroyRequest) GetKeyHandle() *proto.KeyHandle
func (*DestroyRequest) ProtoMessage ¶
func (*DestroyRequest) ProtoMessage()
func (*DestroyRequest) ProtoReflect ¶
func (x *DestroyRequest) ProtoReflect() protoreflect.Message
func (*DestroyRequest) Reset ¶
func (x *DestroyRequest) Reset()
func (*DestroyRequest) String ¶
func (x *DestroyRequest) String() string
type EnumerateKeysResponse ¶
type EnumerateKeysResponse struct {
// A list of active keys along with their metadata.
KeyInfos []*KeyInfo `protobuf:"bytes,1,rep,name=key_infos,json=keyInfos,proto3" json:"key_infos,omitempty"`
// contains filtered or unexported fields
}
Response containing a list of all active keys managed by the daemon.
func (*EnumerateKeysResponse) Descriptor
deprecated
func (*EnumerateKeysResponse) Descriptor() ([]byte, []int)
Deprecated: Use EnumerateKeysResponse.ProtoReflect.Descriptor instead.
func (*EnumerateKeysResponse) GetKeyInfos ¶
func (x *EnumerateKeysResponse) GetKeyInfos() []*KeyInfo
func (*EnumerateKeysResponse) ProtoMessage ¶
func (*EnumerateKeysResponse) ProtoMessage()
func (*EnumerateKeysResponse) ProtoReflect ¶
func (x *EnumerateKeysResponse) ProtoReflect() protoreflect.Message
func (*EnumerateKeysResponse) Reset ¶
func (x *EnumerateKeysResponse) Reset()
func (*EnumerateKeysResponse) String ¶
func (x *EnumerateKeysResponse) String() string
type GenerateKeyRequest ¶
type GenerateKeyRequest struct {
// The specific algorithm to use for the new keypair.
Algorithm *proto.AlgorithmDetails `protobuf:"bytes,1,opt,name=algorithm,proto3" json:"algorithm,omitempty"`
// The requested duration (in seconds) before the key is automatically destroyed.
Lifespan uint64 `protobuf:"varint,2,opt,name=lifespan,proto3" json:"lifespan,omitempty"`
// contains filtered or unexported fields
}
Request to orchestrate the creation of a new keypair (e.g., a KEM keypair). (POST /v1/keys:generate_key)
func (*GenerateKeyRequest) Descriptor
deprecated
func (*GenerateKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use GenerateKeyRequest.ProtoReflect.Descriptor instead.
func (*GenerateKeyRequest) GetAlgorithm ¶
func (x *GenerateKeyRequest) GetAlgorithm() *proto.AlgorithmDetails
func (*GenerateKeyRequest) GetLifespan ¶
func (x *GenerateKeyRequest) GetLifespan() uint64
func (*GenerateKeyRequest) ProtoMessage ¶
func (*GenerateKeyRequest) ProtoMessage()
func (*GenerateKeyRequest) ProtoReflect ¶
func (x *GenerateKeyRequest) ProtoReflect() protoreflect.Message
func (*GenerateKeyRequest) Reset ¶
func (x *GenerateKeyRequest) Reset()
func (*GenerateKeyRequest) String ¶
func (x *GenerateKeyRequest) String() string
type GenerateKeyResponse ¶
type GenerateKeyResponse struct {
// A unique handle (UUID) used to reference the generated key.
KeyHandle *proto.KeyHandle `protobuf:"bytes,1,opt,name=key_handle,json=keyHandle,proto3" json:"key_handle,omitempty"`
// The public key information for the generated keypair.
PubKey *proto.PubKeyInfo `protobuf:"bytes,2,opt,name=pub_key,json=pubKey,proto3" json:"pub_key,omitempty"`
// The isolation level/protection mechanism for the key
// (e.g., "KEY_PROTECTION_VM_EMULATED", "KEY_PROTECTION_VM", or "DEFAULT").
KeyProtectionMechanism string `` /* 129-byte string literal not displayed */
// A Unix timestamp indicating when the key is scheduled for automatic deletion.
// Note: relies on network clock time and is subject to hypervisor clock drift/skew.
ExpirationTime float64 `protobuf:"fixed64,4,opt,name=expiration_time,json=expirationTime,proto3" json:"expiration_time,omitempty"`
// contains filtered or unexported fields
}
Response from generating a new key.
func (*GenerateKeyResponse) Descriptor
deprecated
func (*GenerateKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use GenerateKeyResponse.ProtoReflect.Descriptor instead.
func (*GenerateKeyResponse) GetExpirationTime ¶
func (x *GenerateKeyResponse) GetExpirationTime() float64
func (*GenerateKeyResponse) GetKeyHandle ¶
func (x *GenerateKeyResponse) GetKeyHandle() *proto.KeyHandle
func (*GenerateKeyResponse) GetKeyProtectionMechanism ¶
func (x *GenerateKeyResponse) GetKeyProtectionMechanism() string
func (*GenerateKeyResponse) GetPubKey ¶
func (x *GenerateKeyResponse) GetPubKey() *proto.PubKeyInfo
func (*GenerateKeyResponse) ProtoMessage ¶
func (*GenerateKeyResponse) ProtoMessage()
func (*GenerateKeyResponse) ProtoReflect ¶
func (x *GenerateKeyResponse) ProtoReflect() protoreflect.Message
func (*GenerateKeyResponse) Reset ¶
func (x *GenerateKeyResponse) Reset()
func (*GenerateKeyResponse) String ¶
func (x *GenerateKeyResponse) String() string
type GetCapabilitiesResponse ¶
type GetCapabilitiesResponse struct {
// List of supported algorithms (e.g., KEM algorithms).
SupportedAlgorithms []*proto.SupportedAlgorithm `protobuf:"bytes,1,rep,name=supported_algorithms,json=supportedAlgorithms,proto3" json:"supported_algorithms,omitempty"`
// contains filtered or unexported fields
}
Response containing the list of supported cryptographic algorithms for operations like HPKE/KEM.
func (*GetCapabilitiesResponse) Descriptor
deprecated
func (*GetCapabilitiesResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetCapabilitiesResponse.ProtoReflect.Descriptor instead.
func (*GetCapabilitiesResponse) GetSupportedAlgorithms ¶
func (x *GetCapabilitiesResponse) GetSupportedAlgorithms() []*proto.SupportedAlgorithm
func (*GetCapabilitiesResponse) ProtoMessage ¶
func (*GetCapabilitiesResponse) ProtoMessage()
func (*GetCapabilitiesResponse) ProtoReflect ¶
func (x *GetCapabilitiesResponse) ProtoReflect() protoreflect.Message
func (*GetCapabilitiesResponse) Reset ¶
func (x *GetCapabilitiesResponse) Reset()
func (*GetCapabilitiesResponse) String ¶
func (x *GetCapabilitiesResponse) String() string
type KeyInfo ¶
type KeyInfo struct {
// A unique handle (UUID) used to reference the keypair.
KeyHandle *proto.KeyHandle `protobuf:"bytes,1,opt,name=key_handle,json=keyHandle,proto3" json:"key_handle,omitempty"`
// The public key information for the keypair.
PubKey *proto.PubKeyInfo `protobuf:"bytes,2,opt,name=pub_key,json=pubKey,proto3" json:"pub_key,omitempty"`
// The isolation level/protection mechanism for the key.
KeyProtectionMechanism string `` /* 129-byte string literal not displayed */
// A Unix timestamp indicating when the key will be automatically deleted.
ExpirationTime float64 `protobuf:"fixed64,4,opt,name=expiration_time,json=expirationTime,proto3" json:"expiration_time,omitempty"`
// contains filtered or unexported fields
}
Detailed information about an active key.
func (*KeyInfo) Descriptor
deprecated
func (*KeyInfo) GetExpirationTime ¶
func (*KeyInfo) GetKeyHandle ¶
func (*KeyInfo) GetKeyProtectionMechanism ¶
func (*KeyInfo) GetPubKey ¶
func (x *KeyInfo) GetPubKey() *proto.PubKeyInfo
func (*KeyInfo) ProtoMessage ¶
func (*KeyInfo) ProtoMessage()
func (*KeyInfo) ProtoReflect ¶
func (x *KeyInfo) ProtoReflect() protoreflect.Message